==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/fr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec %s",
    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
    "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vous recevez \"/%3$s\" comme un partage distant depuis %1$s (au nom de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Vous recevez \"/%3$s\" comme un partage distant depuis %1$s",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant Federated Cloud #owncloud",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Voir la documentation",
    "Allow users on this server to send shares to other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs",
    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Votre identifiant Federated Cloud :",
    "Share it:" : "Partager :",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via ownCloud" : "Partagez avec moi via ownCloud",
    "HTML Code:" : "Code HTML :"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/fr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec %s",
    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
    "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vous recevez \"/%3$s\" comme un partage distant depuis %1$s (au nom de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Vous recevez \"/%3$s\" comme un partage distant depuis %1$s",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant Federated Cloud #owncloud %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant Federated Cloud #owncloud",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Voir la documentation",
    "Allow users on this server to send shares to other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs",
    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Votre identifiant Federated Cloud :",
    "Share it:" : "Partager :",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via ownCloud" : "Partagez avec moi via ownCloud",
    "HTML Code:" : "Code HTML :",
    "Add to your ownCloud" : "Ajouter à votre ownCloud"
},
"nplurals=2; plural=(n > 1);");
